// Importing necessary functions from the D3 library
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

// Selecting the SVG element from the DOM
const svg = select('svg');

// Getting the width and height of the SVG element
const width = +svg.attr('width');
const height = +svg.attr('height');

// Function to render the visualization
const render = data => {
  // Defining the x-value accessor function and the x-axis label
  const xValue = d => d.Year;
  const xAxisLabel = 'Year';

  // Defining the y-value accessor function, circle radius, and y-axis label
  const yValue = d => d.population_of_women;
  const circleRadius = 6;
  const yAxisLabel = 'population_of_women';

  // Defining the margin, inner width, and inner height of the visualization
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  // Creating the x-axis scale
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0,innerWidth])
    .nice();

  // Creating the y-axis scale
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();

  // Creating a group element for the visualization and translating it to the appropriate position
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

  // Creating the y-axis with appropriate tick marks and tick labels
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'blue')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);

  // Creating the x-axis with appropriate tick marks and tick labels
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  xAxisG.select('.domain').remove();
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 50)
      .attr('x', innerWidth / 2)
      .attr('fill', 'blue')
      .text(xAxisLabel);

  // Creating the line generator function for the line graph
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
 	  .curve(curveBasis);

  // Adding the line path to the SVG element
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));

  // Adding the title of the visualization
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
//now the gist data is linked 
csv('https://gist.githubusercontent.com/adapavaishnavi12/789bf30a16b5bbf9f1213f242fa653b0/raw/4323fcb85df542e6919ee19a05ceb5b29b917256/population.csv')
  .then(data => {
    data.forEach(d => {
      d.population_of_women = +d.population_of_women;
      d.Year = +d.Year;
    });
    render(data);
  });